==> ideaIC-211.7442.40-sources.jar: com/android/tools/idea/gradle/structure/configurables/ui/dependencies/DependencyInfoPanel.java <==
/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.structure.configurables.ui.dependencies;

import com.android.tools.idea.gradle.structure.configurables.dependencies.details.DependencyDetails;
import com.android.tools.idea.gradle.structure.configurables.issues.IssuesViewer;
import com.android.tools.idea.gradle.structure.configurables.ui.CollapsiblePanel;
import org.jetbrains.annotations.NotNull;

import javax.swing.*;
import java.awt.*;

import static com.android.tools.idea.gradle.structure.configurables.ui.UiUtil.revalidateAndRepaint;

class DependencyInfoPanel {
  private JPanel myMainPanel;
  private JPanel myDependencyDetailsPanel;
  private JPanel myIssuesPanel;

  void setDependencyDetails(@NotNull DependencyDetails details) {
    ((CollapsiblePanel)myDependencyDetailsPanel).setContents(details.getPanel());
    revalidateAndRepaintPanel();
  }

  @NotNull
  JPanel getPanel() {
    return myMainPanel;
  }

  void setIssuesViewer(@NotNull IssuesViewer viewer) {
    myIssuesPanel.add(viewer.getPanel(), BorderLayout.CENTER);
    revalidateAndRepaintPanel();
  }

  private void createUIComponents() {
    myDependencyDetailsPanel = new CollapsiblePanel("Details");
    myIssuesPanel = new JPanel(new BorderLayout());
  }

  void revalidateAndRepaintPanel() {
    revalidateAndRepaint(myMainPanel);
  }
}

==> ideaIC-2018.3.3-sources.jar: com/android/tools/idea/gradle/structure/configurables/ui/dependencies/DependencyInfoPanel.java <==
/*
 * Copyright (C) 2016 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.android.tools.idea.gradle.structure.configurables.ui.dependencies;

import com.android.tools.idea.gradle.structure.configurables.android.dependencies.details.DependencyDetails;
import com.android.tools.idea.gradle.structure.configurables.issues.IssuesViewer;
import com.android.tools.idea.gradle.structure.configurables.ui.CollapsiblePanel;
import org.jetbrains.annotations.NotNull;

import javax.swing.*;
import java.awt.*;

import static com.android.tools.idea.gradle.structure.configurables.ui.UiUtil.revalidateAndRepaint;

class DependencyInfoPanel {
  private JPanel myMainPanel;
  private JPanel myDependencyDetailsPanel;
  private JPanel myIssuesPanel;

  void setDependencyDetails(@NotNull DependencyDetails details) {
    ((CollapsiblePanel)myDependencyDetailsPanel).setContents(details.getPanel());
    revalidateAndRepaintPanel();
  }

  @NotNull
  JPanel getPanel() {
    return myMainPanel;
  }

  void setIssuesViewer(@NotNull IssuesViewer viewer) {
    myIssuesPanel.add(viewer.getPanel(), BorderLayout.CENTER);
    revalidateAndRepaintPanel();
  }

  private void createUIComponents() {
    myDependencyDetailsPanel = new CollapsiblePanel("Details");
    myIssuesPanel = new JPanel(new BorderLayout());
  }

  void revalidateAndRepaintPanel() {
    revalidateAndRepaint(myMainPanel);
  }
}
